@@ -29,11 +29,15 @@
 #'         
 #' @examples
 #' data(PoohPiglet)
-#' PoohPiglet = PoohPiglet[order(factor(PoohPiglet$Speaker, 
-#'                         levels=c("Pooh", "Tigger", "Piglet"))),]
-#' pairwisePermutationTest(x      = PoohPiglet$Likert,
-#'                         g      = PoohPiglet$Speaker,
-#'                         method = "fdr")
+#' PoohPiglet$Speaker = factor(PoohPiglet$Speaker, 
+#'                             levels=c("Pooh", "Tigger", "Piglet"))
+#' PT = pairwisePermutationTest(x      = PoohPiglet$Likert,
+#'                              g      = PoohPiglet$Speaker,
+#'                              method = "fdr")
+#' PT
+#' cldList(comparison = PT$Comparison,
+#'        p.value    = PT$p.adjust,
+#'        threshold  = 0.05)
 #' 
 #' @importFrom stats p.adjust
 #' @importFrom coin independence_test statistic
@@ -43,7 +47,8 @@
 pairwisePermutationTest = 
   function(x, g, method = "fdr", ...)
   {
-  n = length(unique(g))
+  if(!is.factor(g)){g=factor(g)}
+  n = length(levels(g))
   N = n*(n-1)/2
   d = data.frame(x = x, g = g)
   Z = data.frame(Comparison=rep("A", N),
@@ -56,10 +61,10 @@ pairwisePermutationTest =
   for(i in 1:(n-1)){
      for(j in (i+1):n){
        k=k+1
-     Namea = as.character(unique(g)[i])
-     Nameb = as.character(unique(g)[j])
-     Datax = subset(d, g==unique(g)[i])
-     Datay = subset(d, g==unique(g)[j])
+     Namea = as.character(levels(g)[i])
+     Nameb = as.character(levels(g)[j])
+     Datax = subset(d, g==levels(g)[i])
+     Datay = subset(d, g==levels(g)[j])
      Dataz = rbind(Datax, Datay)
      Dataz$g2 = factor(Dataz$g)
      z = independence_test(x ~ g2, data=Dataz, ...)
